@@ -1,10 +1,11 @@
 library(fitdistrplus)
+nsample <- 10
 
 # (1) basic fit of a normal distribution with moment matching estimation
 #
 
 set.seed(1234)
-x1 <- rnorm(n=100)
+x1 <- rnorm(n=nsample)
 mmedist(x1,"norm")
 
 try(mmedist(x1,"norm", fix.arg=list(mean=0)))
@@ -13,14 +14,14 @@ try(mmedist(x1,"norm", fix.arg=list(mean=0)))
 #
 
 set.seed(1234)
-x2 <- rpois(n=30,lambda = 2)
+x2 <- rpois(n=nsample, lambda = 2)
 mmedist(x2,"pois")
 
 # (3) fit a finite-support distribution (beta)
 #
 
 set.seed(1234)
-x3 <- rbeta(n=100,shape1=5, shape2=10)
+x3 <- rbeta(n=nsample, shape1=5, shape2=10)
 mmedist(x3,"beta")
 
 
@@ -30,40 +31,40 @@ mmedist(x3,"beta")
 
 if(any(installed.packages()[, "Package"] == "actuar"))
 {
-    require(actuar)
-    #simulate a sample
-    x4 <- rpareto(1000, 6, 2)
-	
-    #empirical raw moment
-    memp <- function(x, order)
-      mean(x^order)
-		
-    #fit
-    mmedist(x4, "pareto", order=c(1, 2), memp=memp, start=c(shape=10, scale=10), 
-			lower=1, upper=Inf)
-    mmedist(x4, "pareto", order=1, memp=memp, start=list(shape=10), fix.arg=list(scale=1.5), 
-            lower=2, upper=Inf)
-    mmedist(x4, "pareto", order=1, memp=memp, start=function(x) list(shape=10), fix.arg=list(scale=1.5), 
-            lower=2, upper=Inf)
-    mmedist(x4, "pareto", order=1, memp=memp, start=list(shape=10), fix.arg=function(x) list(scale=1.5), 
-            lower=2, upper=Inf)
-    
-    #weights
-    memp2 <- function(x, order, weights) sum(x^order * weights)/sum(weights)
-    w <- rep(1, length(x4))
-    w[x4 < 1] <- 2
-    mmedist(x4, "pareto", order=c(1, 2), memp=memp2, weights=w,
-            start=list(shape=10, scale=10), lower=1, upper=Inf)
-			
-#fit
-data(danishuni)
-fparedanishMME <- mmedist(danishuni$Loss, "pareto", order=1:2, 
-      memp=memp, start=c(shape=10, scale=10), lower=2+1e-6, upper=Inf)
-c(theo = mpareto(1, fparedanishMME$estimate[1], fparedanishMME$estimate[2]),
-emp = memp(danishuni$Loss, 1))	
-c(theo = mpareto(2, fparedanishMME$estimate[1], fparedanishMME$estimate[2]),
-emp = memp(danishuni$Loss, 2))
-	
+  require(actuar)
+  #simulate a sample
+  x4 <- rpareto(nsample, 6, 2)
+  
+  #empirical raw moment
+  memp <- function(x, order)
+    mean(x^order)
+  
+  #fit
+  mmedist(x4, "pareto", order=c(1, 2), memp=memp, start=c(shape=10, scale=10), 
+          lower=1, upper=Inf)
+  mmedist(x4, "pareto", order=1, memp=memp, start=list(shape=10), fix.arg=list(scale=1.5), 
+          lower=2, upper=Inf)
+  mmedist(x4, "pareto", order=1, memp=memp, start=function(x) list(shape=10), fix.arg=list(scale=1.5), 
+          lower=2, upper=Inf)
+  mmedist(x4, "pareto", order=1, memp=memp, start=list(shape=10), fix.arg=function(x) list(scale=1.5), 
+          lower=2, upper=Inf)
+  
+  #weights
+  memp2 <- function(x, order, weights) sum(x^order * weights)/sum(weights)
+  w <- rep(1, length(x4))
+  w[x4 < 1] <- 2
+  mmedist(x4, "pareto", order=c(1, 2), memp=memp2, weights=w,
+          start=list(shape=10, scale=10), lower=1, upper=Inf)
+  
+  #fit
+  data(danishuni)
+  fparedanishMME <- mmedist(danishuni$Loss, "pareto", order=1:2, 
+                            memp=memp, start=c(shape=10, scale=10), lower=2+1e-6, upper=Inf)
+  c(theo = mpareto(1, fparedanishMME$estimate[1], fparedanishMME$estimate[2]),
+    emp = memp(danishuni$Loss, 1))	
+  c(theo = mpareto(2, fparedanishMME$estimate[1], fparedanishMME$estimate[2]),
+    emp = memp(danishuni$Loss, 2))
+  
 }
 
 
@@ -79,12 +80,12 @@ cbind(c(mu, s2), f2$estimate)
 
 
 c(truestim=exp(mu+s2/2), 
-	jensen=as.numeric(exp(f1$estimate["meanlog"]+f1$estimate["sdlog"]^2/2)), 
-	emp=mean(x3))
+  jensen=as.numeric(exp(f1$estimate["meanlog"]+f1$estimate["sdlog"]^2/2)), 
+  emp=mean(x3))
 
 c(truestim=exp(2*mu+s2)*(exp(s2)-1), 
-	jensen=as.numeric(exp(2*f1$estimate["meanlog"]+f1$estimate["sdlog"]^2)*(exp(f1$estimate["sdlog"]^2)-1)), 
-	emp=var(x3)*(n-1)/n)
+  jensen=as.numeric(exp(2*f1$estimate["meanlog"]+f1$estimate["sdlog"]^2)*(exp(f1$estimate["sdlog"]^2)-1)), 
+  emp=var(x3)*(n-1)/n)
 
 
 # (6) test error messages
@@ -92,7 +93,7 @@ c(truestim=exp(2*mu+s2)*(exp(s2)-1),
 
 mnorm3 <- dnorm3 <- function(x, a)
   "NA"
-x <- rnorm(10)
+x <- rnorm(nsample)
 
 #should get a one-line error 
 res <- mmedist(x, "norm3", start=list(a=1), order=1, memp=function(x, order) mean(x))
@@ -103,7 +104,7 @@ attr(try(log("a"), silent=TRUE), "condition")
 # (7) fit of a normal distribution with weighted moment matching estimation
 #
 
-n <- length(x1)
+n <- nsample
 w <- c(rep(1, n/2), rep(10, n/2))
 mmedist(x1, "norm", weights=w)$estimate
 
@@ -125,10 +126,10 @@ try(mmedist(1:10, "pois", weights=c(rep(1, 9), 1.0000001), start=list(lambda=mea
 # (8) fit of a neg binom distribution with weighted moment matching estimation
 #
 
-x4 <- rnbinom(100, 5, 1/2)
+x4 <- rnbinom(nsample, 5, 1/2)
 table(x4)
 w <- rep(1, length(x4))
-w[x4 > 10] <- 2
+w[x4 > 5] <- 2
 
 mmedist(x4, "nbinom", weights=w)$estimate
 mmedist(x4, "nbinom", weights=NULL)$estimate
@@ -154,9 +155,11 @@ mgeom <- function(order, prob)
   else
     stop("not yet implemented")
 }
-c(mean(rgeom(1e4, 1/6)), mgeom(1, 1/6))
-c(mean(rgeom(1e4, 1/6)^2), mgeom(2, 1/6))
-
+if(FALSE)
+{
+  c(mean(rgeom(1e4, 1/6)), mgeom(1, 1/6))
+  c(mean(rgeom(1e4, 1/6)^2), mgeom(2, 1/6))
+}
 
 mzmgeom <- function(order, p1, p2) #raw moment
 {
@@ -167,16 +170,18 @@ mzmgeom <- function(order, p1, p2) #raw moment
   else
     stop("not yet implemented")
 }
-c(mean(rzmgeom(1e4, 1/3, 1/6)), mzmgeom(1, 1/3, 1/6))
-c(mean(rzmgeom(1e4, 1/3, 1/6)^2), mzmgeom(2, 1/3, 1/6))
-
+if(FALSE)
+{
+  c(mean(rzmgeom(1e4, 1/3, 1/6)), mzmgeom(1, 1/3, 1/6))
+  c(mean(rzmgeom(1e4, 1/3, 1/6)^2), mzmgeom(2, 1/3, 1/6))
+}
 
 memp1 <- function(x, order) mean(x^order)
 memp2 <- function(x, order, weights) sum(x^order * weights)/sum(weights)
 
-x5 <- rzmgeom(1e4, 1/3, 1/6)
+x5 <- rzmgeom(nsample, 1/3, 1/6)
 w <- rep(1, length(x5))
-w[x5 > 20] <- 2
+w[x5 > 5] <- 2
 
 mmedist(x5, "zmgeom", order=1:2, memp=memp1, start=list(p1=mean(x5 == 0), p2=1/mean(x5[x5 > 0])), 
         lower=0.01, upper=0.99)$estimate
@@ -195,7 +200,7 @@ if(any(installed.packages()[, "Package"] == "actuar"))
 {
   require(actuar)
   #simulate a sample
-  x4 <- rpareto(1000, 6, 2)
+  x4 <- rpareto(nsample, 6, 2)
   
   #empirical raw moment
   memp <- function(x, order)
